--[[
Script to add the manual discharge configuration to an vehicle

Author:		Ifko[nator]
Date:		01.04.2020
Version:	1.0

History:	V 1.0 @ 01.04.2020 - initial release in FS 19
]]

function registerConfiguration()
    if g_configurationManager.configurations["manualDischarge"] == nil then    
        g_configurationManager:addConfigurationType("manualDischarge", g_i18n:getText("configuration_manualDischarge"), nil, nil, nil, nil, ConfigurationUtil.SELECTOR_MULTIOPTION);
    end;
    
	StoreItemUtil.getConfigurationsFromXML = Utils.overwrittenFunction(StoreItemUtil.getConfigurationsFromXML, addConfiguration);
end;

function addConfiguration(xmlFile, superFunc, baseXMLName, baseDir, customEnvironment, isMod, storeItem)
	local configurations = superFunc(xmlFile, baseXMLName, baseDir, customEnvironment, isMod, storeItem);
    
    if configurations ~= nil then
        local specs = storeItem.specs;
        local manualDischargeKey = "manualDischarge";
        local vehicleXML = loadXMLFile("vehicle", storeItem.xmlFilename);
        local hasPipeAndFillVolume = hasXMLProperty(vehicleXML, "vehicle.pipe") and (hasXMLProperty(vehicleXML, "vehicle.fillVolume") and not hasXMLProperty(vehicleXML, "vehicle.woodCrusher"));

	    if g_configurationManager.configurations[manualDischargeKey] ~= nil then
            if hasPipeAndFillVolume then
                --## Dirty stuff.. but the only "solid" way.
                if configurations[manualDischargeKey] == nil then
                    local entryNoManualDischarge = {
                        desc = "",
                        price = 0,
                        dailyUpkeep = 0,
                        isDefault = false,
                        index = 1,
                        name = g_i18n:getText("ui_no"),
                        enabled = true
	    			};
                
                    local entryManualDischarge = {
                        desc = "",
                        price = 0,
                        dailyUpkeep = 0,
                        isDefault = true,
                        index = 2,
                        name = g_i18n:getText("ui_yes"),
                        enabled = false
                    };
	    			configurations[manualDischargeKey] = {};
                
                    table.insert(configurations[manualDischargeKey], entryNoManualDischarge);
                    table.insert(configurations[manualDischargeKey], entryManualDischarge);
                else
                    --## Add enabled values to added xml configurations
                    for id, configuration in pairs(configurations[manualDischargeKey]) do
                        configuration.enabled = id > 1;
                    end;
                end;
            end;
        end;

        delete(vehicleXML);
    end;

    return configurations;
end;

Vehicle.init = Utils.appendedFunction(Vehicle.init, registerConfiguration);